@@ -1,7 +1,7 @@
 /*
 |  Copyright (C) 2002-2007 Jorg Schuler <jcsjcs at users sourceforge net>
 |  Part of the gtkpod project.
-| 
+|
 |  URL: http://www.gtkpod.org/
 |  URL: http://gtkpod.sourceforge.net/
 |
@@ -32,12 +32,9 @@
 
 #include <stdlib.h>
 #include <time.h>
-
-#include "display.h"
-#include "misc.h"
-
-/* path to gtkpod.glade */
-gchar *xml_file = NULL;
+#include <libintl.h>
+#include "gtkpod.h"
+#include <glib/gi18n-lib.h>
 
 int
 main (int argc, char *argv[])
@@ -56,18 +53,14 @@ main (int argc, char *argv[])
     gdk_threads_init ();
 #endif
 
-    gdk_threads_enter ();
-
     gtk_init (&argc, &argv);
+    g_set_application_name(_("gtkpod"));
+    gtk_window_set_auto_startup_notification(FALSE);
 
     srand(time(NULL));
 
     gtkpod_init (argc, argv);
-
     gtk_main ();
 
-    gdk_threads_leave ();
-
-    /* all the cleanup is already done in gtkpod_main_shutdown () in misc.c */
     return 0;
 }
